@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -10,7 +10,8 @@
 #include "pimcommon_export.h"
 #include <QObject>
 class KActionCollection;
-namespace PimCommon {
+namespace PimCommon
+{
 class CustomToolsWidgetNg;
 class CustomToolsViewInterface;
 class CustomToolsPluginPrivate;
@@ -23,7 +24,7 @@ class PIMCOMMON_EXPORT CustomToolsPlugin : public QObject
     Q_OBJECT
 public:
     explicit CustomToolsPlugin(QObject *parent = nullptr);
-    ~CustomToolsPlugin();
+    ~CustomToolsPlugin() override;
 
     virtual PimCommon::CustomToolsViewInterface *createView(KActionCollection *ac, CustomToolsWidgetNg *parent = nullptr) = 0;
     Q_REQUIRED_RESULT virtual QString customToolName() const = 0;
