@@ -1,44 +1,32 @@
 /*
-  Copyright (c) 2013-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "templateeditdialog.h"
-#include "kpimtextedit/plaintexteditorwidget.h"
-#include "kpimtextedit/plaintexteditor.h"
+#include <KPIMTextEdit/PlainTextEditor>
+#include <KPIMTextEdit/PlainTextEditorWidget>
+#include <Libkdepim/LineEditCatchReturnKey>
 
 #include <KLocalizedString>
-#include <KLineEdit>
+#include <QLineEdit>
 
-#include <QVBoxLayout>
+#include <KConfigGroup>
+#include <KSharedConfig>
+#include <QDialogButtonBox>
 #include <QHBoxLayout>
 #include <QLabel>
-#include <KSharedConfig>
-#include <KConfigGroup>
-#include <QDialogButtonBox>
 #include <QPushButton>
+#include <QVBoxLayout>
 
 using namespace PimCommon;
 
 TemplateEditDialog::TemplateEditDialog(QWidget *parent, bool defaultTemplate)
     : QDialog(parent)
-    , mOkButton(nullptr)
 {
     setWindowTitle(defaultTemplate ? i18n("Default template") : i18n("Template"));
-    QVBoxLayout *mainLayout = new QVBoxLayout(this);
+    auto mainLayout = new QVBoxLayout(this);
     QDialogButtonBox *buttonBox = nullptr;
     if (defaultTemplate) {
         buttonBox = new QDialogButtonBox(QDialogButtonBox::Close, this);
@@ -52,19 +40,19 @@ TemplateEditDialog::TemplateEditDialog(QWidget *parent, bool defaultTemplate)
         connect(buttonBox, &QDialogButtonBox::rejected, this, &TemplateEditDialog::reject);
         mOkButton->setFocus();
     }
-    QWidget *w = new QWidget;
+    auto w = new QWidget;
     mainLayout->addWidget(w);
     mainLayout->addWidget(buttonBox);
 
-    QVBoxLayout *vbox = new QVBoxLayout;
+    auto vbox = new QVBoxLayout;
     vbox->setContentsMargins(0, 0, 0, 0);
 
-    QHBoxLayout *hbox = new QHBoxLayout;
-    QLabel *label = new QLabel(i18n("Name:"));
+    auto hbox = new QHBoxLayout;
+    auto label = new QLabel(i18n("Name:"));
     hbox->addWidget(label);
 
-    mTemplateNameEdit = new KLineEdit;
-    mTemplateNameEdit->setTrapReturnKey(true);
+    mTemplateNameEdit = new QLineEdit;
+    new KPIM::LineEditCatchReturnKey(mTemplateNameEdit, this);
     mTemplateNameEdit->setClearButtonEnabled(!defaultTemplate);
     mTemplateNameEdit->setReadOnly(defaultTemplate);
     hbox->addWidget(mTemplateNameEdit);
