@@ -1,19 +1,7 @@
 /*
-  Copyright (c) 2013-2019 Montel Laurent <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #ifndef TEMPLATEMANAGER_H
@@ -22,7 +10,8 @@
 #include "pimcommon_export.h"
 #include <QObject>
 
-namespace PimCommon {
+namespace PimCommon
+{
 class TemplateListWidget;
 struct TemplateInfo {
     QString name;
@@ -35,12 +24,16 @@ struct TemplateInfo {
     void debug() const;
 };
 class TemplateManagerPrivate;
+/**
+ * @brief The TemplateManager class
+ * @author Laurent Montel <montel@kde.org>
+ */
 class PIMCOMMON_EXPORT TemplateManager : public QObject
 {
     Q_OBJECT
 public:
     explicit TemplateManager(const QString &relativeTemplateDir, PimCommon::TemplateListWidget *sieveTemplateWidget);
-    ~TemplateManager();
+    ~TemplateManager() override;
 
 private:
     void slotDirectoryChanged();
