@@ -1,6 +1,6 @@
 /*
 
-  SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -10,9 +10,10 @@
 
 #include "pimcommon_export.h"
 #include <KPIMTextEdit/PlainTextEditor>
-#include <kio/job.h>
 #include <KPIMTextEdit/PlainTextEditorWidget>
-namespace PimCommon {
+#include <kio/job.h>
+namespace PimCommon
+{
 class TranslatorResultTextEdit : public KPIMTextEdit::PlainTextEditor
 {
     Q_OBJECT
