@@ -4,23 +4,23 @@
     This file is part of KMail, the KDE mail client.
     SPDX-FileCopyrightText: 2001 Marc Mutz <mutz@kde.org>
 
-    SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "simplestringlisteditor.h"
 
-#include <QInputDialog>
-#include <QIcon>
+#include "pimcommon_debug.h"
 #include <KLocalizedString>
 #include <KMessageBox>
-#include "pimcommon_debug.h"
-#include <QPushButton>
-#include <QMenu>
-#include <QVBoxLayout>
 #include <QHBoxLayout>
+#include <QIcon>
+#include <QInputDialog>
 #include <QListWidget>
+#include <QMenu>
+#include <QPushButton>
+#include <QVBoxLayout>
 
 //********************************************************
 // SimpleStringListEditor
@@ -55,16 +55,24 @@ public:
     QPushButton *mCustomButton = nullptr;
     QVBoxLayout *mButtonLayout = nullptr;
     QString mAddDialogLabel = i18n("New entry:");
+    QString mAddDialogTitle = i18n("New Value");
+    QString mModifyDialogTitle = i18n("New Value");
+    QString mModifyDialogLabel = i18n("New entry:");
     QString mRemoveDialogLabel = i18n("Do you want to remove selected text?");
 };
 
-SimpleStringListEditor::SimpleStringListEditor(QWidget *parent, ButtonCode buttons, const QString &addLabel, const QString &removeLabel, const QString &modifyLabel, const QString &addDialogLabel)
+SimpleStringListEditor::SimpleStringListEditor(QWidget *parent,
+                                               ButtonCode buttons,
+                                               const QString &addLabel,
+                                               const QString &removeLabel,
+                                               const QString &modifyLabel,
+                                               const QString &addDialogLabel)
     : QWidget(parent)
     , d(new SimpleStringListEditorPrivate)
 {
     setAddDialogLabel(addDialogLabel);
     setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::MinimumExpanding);
-    auto *hlay = new QHBoxLayout(this);
+    auto hlay = new QHBoxLayout(this);
     hlay->setContentsMargins(0, 0, 0, 0);
 
     d->mListBox = new QListWidget(this);
@@ -101,7 +109,7 @@ SimpleStringListEditor::SimpleStringListEditor(QWidget *parent, ButtonCode butto
             d->mModifyButton = new QPushButton(modifyLabel, this);
         }
         d->mModifyButton->setAutoDefault(false);
-        d->mModifyButton->setEnabled(false);   // no selection yet
+        d->mModifyButton->setEnabled(false); // no selection yet
         d->mButtonLayout->addWidget(d->mModifyButton);
         connect(d->mModifyButton, &QPushButton::clicked, this, &SimpleStringListEditor::slotModify);
         connect(d->mListBox, &QListWidget::itemDoubleClicked, this, &SimpleStringListEditor::slotModify);
@@ -114,7 +122,7 @@ SimpleStringListEditor::SimpleStringListEditor(QWidget *parent, ButtonCode butto
             d->mRemoveButton = new QPushButton(removeLabel, this);
         }
         d->mRemoveButton->setAutoDefault(false);
-        d->mRemoveButton->setEnabled(false);   // no selection yet
+        d->mRemoveButton->setEnabled(false); // no selection yet
         d->mButtonLayout->addWidget(d->mRemoveButton);
         connect(d->mRemoveButton, &QPushButton::clicked, this, &SimpleStringListEditor::slotRemove);
     }
@@ -127,7 +135,7 @@ SimpleStringListEditor::SimpleStringListEditor(QWidget *parent, ButtonCode butto
         d->mUpButton = new QPushButton(QString(), this);
         d->mUpButton->setIcon(QIcon::fromTheme(QStringLiteral("go-up")));
         d->mUpButton->setAutoDefault(false);
-        d->mUpButton->setEnabled(false);   // no selection yet
+        d->mUpButton->setEnabled(false); // no selection yet
         d->mButtonLayout->addWidget(d->mUpButton);
         connect(d->mUpButton, &QPushButton::clicked, this, &SimpleStringListEditor::slotUp);
     }
@@ -140,7 +148,7 @@ SimpleStringListEditor::SimpleStringListEditor(QWidget *parent, ButtonCode butto
         d->mDownButton = new QPushButton(QString(), this);
         d->mDownButton->setIcon(QIcon::fromTheme(QStringLiteral("go-down")));
         d->mDownButton->setAutoDefault(false);
-        d->mDownButton->setEnabled(false);   // no selection yet
+        d->mDownButton->setEnabled(false); // no selection yet
         d->mButtonLayout->addWidget(d->mDownButton);
         connect(d->mDownButton, &QPushButton::clicked, this, &SimpleStringListEditor::slotDown);
     }
@@ -148,12 +156,12 @@ SimpleStringListEditor::SimpleStringListEditor(QWidget *parent, ButtonCode butto
     if (buttons & Custom) {
         d->mCustomButton = new QPushButton(i18n("&Customize..."), this);
         d->mCustomButton->setAutoDefault(false);
-        d->mCustomButton->setEnabled(false);   // no selection yet
+        d->mCustomButton->setEnabled(false); // no selection yet
         d->mButtonLayout->addWidget(d->mCustomButton);
         connect(d->mCustomButton, &QPushButton::clicked, this, &SimpleStringListEditor::slotCustomize);
     }
 
-    d->mButtonLayout->addStretch(1);   // spacer
+    d->mButtonLayout->addStretch(1); // spacer
 
     connect(d->mListBox, &QListWidget::currentItemChanged, this, &SimpleStringListEditor::slotSelectionChanged);
     connect(d->mListBox, &QListWidget::itemSelectionChanged, this, &SimpleStringListEditor::slotSelectionChanged);
@@ -254,9 +262,7 @@ void SimpleStringListEditor::setButtonText(ButtonCode button, const QString &tex
 void SimpleStringListEditor::addNewEntry()
 {
     bool ok = false;
-    const QString newEntry = QInputDialog::getText(this, i18n("New Value"),
-                                                   d->mAddDialogLabel, QLineEdit::Normal, QString(),
-                                                   &ok);
+    const QString newEntry = QInputDialog::getText(this, d->mAddDialogTitle, d->mAddDialogLabel, QLineEdit::Normal, QString(), &ok);
     if (ok && !newEntry.trimmed().isEmpty()) {
         insertNewEntry(newEntry);
     }
@@ -294,7 +300,7 @@ void SimpleStringListEditor::slotCustomize()
 
 QString SimpleStringListEditor::customEntry(const QString &text)
 {
-    Q_UNUSED(text);
+    Q_UNUSED(text)
     return {};
 }
 
@@ -316,9 +322,7 @@ void SimpleStringListEditor::slotRemove()
 QString SimpleStringListEditor::modifyEntry(const QString &text)
 {
     bool ok = false;
-    QString newText = QInputDialog::getText(this, i18n("Change Value"),
-                                            d->mAddDialogLabel, QLineEdit::Normal, text,
-                                            &ok);
+    QString newText = QInputDialog::getText(this, d->mModifyDialogTitle, d->mModifyDialogLabel, QLineEdit::Normal, text, &ok);
     Q_EMIT aboutToAdd(newText);
 
     if (!ok || newText.trimmed().isEmpty() || newText == text) {
@@ -351,6 +355,21 @@ void SimpleStringListEditor::setAddDialogLabel(const QString &addDialogLabel)
     d->mAddDialogLabel = addDialogLabel;
 }
 
+void SimpleStringListEditor::setAddDialogTitle(const QString &str)
+{
+    d->mAddDialogTitle = str;
+}
+
+void SimpleStringListEditor::setModifyDialogTitle(const QString &str)
+{
+    d->mModifyDialogTitle = str;
+}
+
+void SimpleStringListEditor::setModifyDialogLabel(const QString &str)
+{
+    d->mModifyDialogLabel = str;
+}
+
 void SimpleStringListEditor::slotUp()
 {
     QList<QListWidgetItem *> listWidgetItem = d->selectedItems();
@@ -441,13 +460,10 @@ void SimpleStringListEditor::slotSelectionChanged()
     }
 
     if (d->mUpButton) {
-        d->mUpButton->setEnabled(aItemIsSelected && ((uniqItemSelected && !theFirst)
-                                                     || (!uniqItemSelected)) && !allItemSelected);
+        d->mUpButton->setEnabled(aItemIsSelected && ((uniqItemSelected && !theFirst) || (!uniqItemSelected)) && !allItemSelected);
     }
     if (d->mDownButton) {
-        d->mDownButton->setEnabled(aItemIsSelected
-                                   && ((uniqItemSelected && !theLast)
-                                       || (!uniqItemSelected)) && !allItemSelected);
+        d->mDownButton->setEnabled(aItemIsSelected && ((uniqItemSelected && !theLast) || (!uniqItemSelected)) && !allItemSelected);
     }
 }
 
