@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -7,11 +7,13 @@
 #ifndef ADDRESSEELINEEDITAKONADI_H
 #define ADDRESSEELINEEDITAKONADI_H
 
-namespace Akonadi {
+namespace Akonadi
+{
 class Session;
 }
 
-namespace PimCommon {
+namespace PimCommon
+{
 /**
  * @brief The AddresseeLineEditAkonadi class
  * @author Laurent Montel <montel@kde.org>
