@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -9,7 +9,8 @@
 
 #include <QStringList>
 
-namespace PimCommon {
+namespace PimCommon
+{
 class BalooCompletionEmail;
 class AddresseeLineEditBaloo
 {
@@ -25,6 +26,7 @@ public:
 
     void loadBalooBlackList();
     Q_REQUIRED_RESULT QStringList cleanupEmailList(const QStringList &inputList);
+
 private:
     PimCommon::BalooCompletionEmail *const mBalooCompletionEmail;
     QStringList mBalooBlackList;
