@@ -1,18 +1,18 @@
 /*
-  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
 */
 
 #include "completionconfiguredialog.h"
+#include <KConfigGroup>
+#include <KLDAP/LdapClientSearch>
 #include <KLocalizedString>
-#include <QVBoxLayout>
+#include <KSharedConfig>
 #include <QDialogButtonBox>
 #include <QTabWidget>
-#include <KConfigGroup>
-#include <KSharedConfig>
-#include <KLDAP/LdapClientSearch>
+#include <QVBoxLayout>
 
 #include <addressline/completionorder/completionorderwidget.h>
 #include <config-akonadi-search.h>
@@ -43,7 +43,7 @@ CompletionConfigureDialog::CompletionConfigureDialog(QWidget *parent)
     , d(new PimCommon::CompletionConfigureDialogPrivate)
 {
     setWindowTitle(i18nc("@title:window", "Configure Completion"));
-    auto *mainLayout = new QVBoxLayout(this);
+    auto mainLayout = new QVBoxLayout(this);
 
     d->mTabWidget = new QTabWidget(this);
     d->mTabWidget->setObjectName(QStringLiteral("tabwidget"));
@@ -63,7 +63,7 @@ CompletionConfigureDialog::CompletionConfigureDialog(QWidget *parent)
     d->mTabWidget->addTab(d->mBlackListBalooWidget, i18n("Blacklist Email Address"));
 #endif
 
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
+    auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
     buttonBox->setObjectName(QStringLiteral("buttonbox"));
     connect(buttonBox, &QDialogButtonBox::accepted, this, &CompletionConfigureDialog::slotSave);
     connect(buttonBox, &QDialogButtonBox::rejected, this, &QDialog::reject);
